@@ -1,18 +1,20 @@
 #' @title Encrypt a string
 #'
-#' @description \code{encrypt_string} encrypts a string as a string and
-#'   \code{decrypt_string} decrypts the encrypted string(encrypted using
-#'   \code{encrypt_string})
+#' @description \code{encrypt_string} encrypts a string as a string or a raw
+#'   vector and \code{decrypt_string} decrypts the encrypted string or a raw
+#'   vector (encrypted using \code{encrypt_string})
 #'
 #' @param string A string(character vector of length 1) without embedded NULL to
-#'   be encrypted.
+#'   be encrypted or a raw vector.
 #' @param key For symmetric encryption, 'pkey' should be NULL (default) and
 #'   'key' can be either a string (Default is 'pass') or a raw object. For
 #'   asymmetric encryption, both 'key' (private key of the encrypter) and 'pkey'
 #'   (public key of the decrypter) should be raw objects.
 #' @param pkey See 'key'
+#' @param ascii (flag) When TRUE (default), the output is a string after base64
+#'   encoding. Else, the output is a raw vector.
 #'
-#' @return An encrypted string
+#' @return An encrypted string or a raw vector.
 #'
 #' @examples
 #' # symmetric case:
@@ -23,6 +25,12 @@
 #'   , class(try(decrypt_string(temp, "nopass"), silent = TRUE)) == "try-error"
 #'   )
 #'
+#' # string encoded as raw
+#' res <- encrypt_string("tatvamasi", ascii = FALSE)
+#' res
+#'
+#' isTRUE(identical(decrypt_string(res), "tatvamasi"))
+#'
 #' # asymmetric case:
 #' alice <- keypair()
 #' bob   <- keypair()
@@ -35,6 +43,7 @@
 encrypt_string <- function(string
                            , key    = "pass"
                            , pkey   = NULL
+                           , ascii  = TRUE
                            ){
 
   assert_that(is.string(string))
@@ -48,6 +57,8 @@ encrypt_string <- function(string
     assert_that(is.raw(pkey))
   }
 
+  assert_that(is.flag(ascii))
+
   if(is.string(key)){
     keyAsRaw <- try(hash(charToRaw(key)), silent = TRUE)
     if(is.error(keyAsRaw)){
@@ -76,25 +87,30 @@ encrypt_string <- function(string
                                    )
   }
 
-  string_enc <- base64encode(string_enc_raw)
-  return(string_enc)
+  attr(string_enc_raw, "nonce") <- NULL
+
+  if(ascii){
+    return( base64encode(string_enc_raw) )
+  } else {
+    return( string_enc_raw )
+  }
 }
 
-#' @title Decrypt a string
+#' @title Decrypt a string or a raw vector
 #'
-#' @description \code{encrypt_string} encrypts a string as a string and
-#'   \code{decrypt_string} decrypts the encrypted string(encrypted using
+#' @description \code{encrypt_string} encrypts a string as a string or a raw vector and
+#'   \code{decrypt_string} decrypts the encrypted string or a raw vector (encrypted using
 #'   \code{encrypt_string})
 #'
 #' @param string A string(character vector of length 1) without embedded NULL to
-#'   be encrypted.
+#'   be encrypted. or a raw vector.
 #' @param key For symmetric decryption, 'pkey' should be NULL (default) and
 #'   'key' can be either a string (Default is 'pass') or a raw object. For
 #'   asymmetric decryption, both 'key' (private key of the decrypter) and 'pkey'
 #'   (public key of the encrypter) should be raw objects.
 #' @param pkey See 'key'
 #'
-#' @return An encrypted string
+#' @return decrypted string
 #'
 #' @examples
 #' # symmetric case:
@@ -105,6 +121,12 @@ encrypt_string <- function(string
 #'   , class(try(decrypt_string(temp, "nopass"), silent = TRUE)) == "try-error"
 #'   )
 #'
+#' # string encoded as raw
+#' res <- encrypt_string("tatvamasi", ascii = FALSE)
+#' res
+#'
+#' isTRUE(identical(decrypt_string(res), "tatvamasi"))
+#'
 #' # asymmetric case:
 #' alice <- keypair()
 #' bob   <- keypair()
@@ -119,7 +141,7 @@ decrypt_string <- function(string
                            , pkey = NULL
                            ){
 
-  assert_that(is.string(string))
+  assert_that(is.string(string) || is.raw(string))
 
   if(is.null(pkey)){
     method <- "symmetric"
@@ -130,10 +152,13 @@ decrypt_string <- function(string
     assert_that(is.raw(pkey))
   }
 
-
-  stringAsRaw <- try(base64decode(string), silent = TRUE)
-  if(is.error(stringAsRaw)){
-    stop("Unable to decode string. Ensure that the input was generated by 'encrypt_string' function")
+  if(is.string(string)){
+    stringAsRaw <- try(base64decode(string), silent = TRUE)
+    if(is.error(stringAsRaw)){
+      stop("Unable to decode string. Ensure that the input was generated by 'encrypt_string' function")
+    }
+  } else {
+    stringAsRaw <- string
   }
 
   if(is.string(key)){
